@@ -3,6 +3,7 @@ from __future__ import absolute_import
 from dataplicity.app.subcommand import SubCommand
 from dataplicity.app import comms
 from dataplicity.client import Client
+from dataplicity.client.exceptions import ForceRestart, ClientException
 from dataplicity import constants
 from dataplicity.client import settings
 
@@ -12,13 +13,14 @@ import sys
 import os
 import time
 import socket
-from threading import Thread, Event
+from threading import Event, Thread
 from os.path import abspath
 import logging
 
 
 class Daemon(object):
     """Dataplicity device management process"""
+
     def __init__(self,
                  conf_path=None,
                  foreground=False,
@@ -39,7 +41,6 @@ class Daemon(object):
         self.pid_path = abspath(conf.get('daemon', 'pidfile', '/var/run/dataplicity.pid'))
 
         self.server_closing_event = Event()
-        #self.comms = comms.Comms()
 
         # Command to execute with the daemon exits
         self.exit_command = None
@@ -53,8 +54,7 @@ class Daemon(object):
             return None
 
     def _push_wait(self, client, event, sync_func):
-        return
-        client.connect_wait(event=event, sync_func=sync_func)
+        client.connect_wait(event, sync_func)
 
     def exit(self, command=None):
         """Exit daemon now, and run optional command"""
@@ -67,16 +67,12 @@ class Daemon(object):
 
         server_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
-        try:
-            self.client.sync()
-        except:
-            self.log.exception("sync failed")
         self.client.tasks.start()
         self.log.debug('ready')
         sync_push_thread = Thread(target=self._push_wait,
                                   args=(self.client,
                                         self.server_closing_event,
-                                        lambda: None))
+                                        self.sync_now))
         sync_push_thread.daemon = True
         try:
             if not self.foreground:
@@ -100,6 +96,13 @@ class Daemon(object):
 
             try:
                 while not self.exit_event.isSet():
+                    try:
+                        self.poll(time.time())
+                    except ClientException:
+                        raise
+                    except Exception as e:
+                        self.log.exception('error in poll')
+
                     try:
                         client, _address = server_socket.accept()
                     except socket.timeout:
@@ -108,12 +111,6 @@ class Daemon(object):
                         self.handle_client_command(client)
                         continue
 
-                    try:
-                        self.poll(time.time())
-                        #time.sleep(0.25)
-                    except Exception as e:
-                        self.log.exception('error in poll')
-
             except SystemExit:
                 self.log.debug("exit requested")
                 return
@@ -122,6 +119,10 @@ class Daemon(object):
                 self.log.debug("user Exit")
                 return
 
+        except ForceRestart:
+            self.log.info('restarting...')
+            self.exit(' '.join(sys.argv))
+
         except Exception as e:
             self.log.exception('error in daemon main loop')
 
@@ -136,10 +137,9 @@ class Daemon(object):
             self.log.debug("closing")
             self.server_closing_event.set()
             self.client.tasks.stop()
-            sync_push_thread.join(2)
             self.log.debug("goodbye")
 
-            if self.exit_event.isSet() and self.exit_command is not None:
+            if self.exit_event.is_set() and self.exit_command is not None:
                 time.sleep(1)  # Maybe redundant
                 self.log.debug("Executing %s" % self.exit_command)
                 os.system(self.exit_command)
@@ -152,6 +152,8 @@ class Daemon(object):
             t = time.time()
         try:
             self.client.sync()
+        except ClientException:
+            raise
         except Exception:
             self.log.exception('sync failed')
 
@@ -200,11 +202,11 @@ class Daemon(object):
         return "BADCOMMAND"
 
 
-class FlushFile(file):
-    def write(self, data):
-        ret = super(FlushFile, self).write(data)
-        self.flush()
-        return ret
+# class FlushFile(file):
+#     def write(self, data):
+#         ret = super(FlushFile, self).write(data)
+#         self.flush()
+#         return ret
 
 
 class D(SubCommand):
@@ -232,7 +234,10 @@ class D(SubCommand):
         conf_path = abspath(conf_path)
 
         conf = settings.read(conf_path)
-        conf_path = conf.get('daemon', 'conf', conf_path)
+        firmware_conf_path = conf.get('daemon', 'conf', conf_path)
+        # It may not exist if there is no installed firmware
+        if os.path.exists(firmware_conf_path):
+            conf_path = firmware_conf_path
 
         if debug is None:
             debug = self.args.debug or self.args.foreground
